@@ -1,4 +1,5 @@
+import videobox
 import videobox.main as main
 # This script is here only for to make easier in VSCode to start a debug session
-#videobox.DEBUG = True
+videobox.DEBUG = True
 main.run()
\ No newline at end of file
